@@ -83,9 +83,6 @@ class ServerVerifier(type):
 
 
 class Core(threading.Thread, metaclass=ServerVerifier):
-    """Класс обработки сообщений и работы с сокетами. Принимает:
-    базу данных, ip-адрес сервера, порт сервера
-    """
     serv_port = CheckoutPort()
 
     def __init__(self, database, serv_ip, serv_port):
@@ -109,9 +106,6 @@ class Core(threading.Thread, metaclass=ServerVerifier):
 
     @log
     def handle_connection(self, msg, cli_sock):
-        """Метод обрабатывает сообщение и отправляет ответы или запускает другие методы. Принимает:
-        сообщение, сокет отправитель
-        """
         LOGGER.debug(f'Проверка типа сообщения: {msg}')
         if ACTION in msg:
             if TIME in msg and USER in msg:
@@ -252,45 +246,35 @@ class Core(threading.Thread, metaclass=ServerVerifier):
             return
 
     @log
-    def handle_message(self, msg, send_socks):
-        """Метод обрабатывает и перенаправляет текстовое сообщение. Принимает:
-        сообщение, сокеты-отправители
-        """
-        dest_name, in_name = msg[DESTINATION], msg[SENDER]
-        LOGGER.debug(f'{dest_name=} {in_name=}')
-        # Получатель задан?
-        if dest_name == '':
+    def handle_message(self, msg, send_sock):
+        dest_cli, send_cli = msg[DESTINATION], msg[SENDER]
+        LOGGER.debug(f'{dest_cli=} {send_cli=}')
+        if dest_cli == '':
             LOGGER.debug(f'Отправляю сообщение [ВСЕМ]: {msg}')
-            for every_cli in send_socks:
+            for every_cli in send_sock:
                 send_message(every_cli, msg)
-            LOGGER.info(f'[{in_name}] => [ВСЕМ]: {msg[MESSAGE_TEXT]}')
-        # Имя получателя в списке клиентов?
-        elif dest_name in self.clients:
-            send_message(self.clients[dest_name], msg)
-            LOGGER.info(f'[{in_name}] => [{dest_name}]: {msg[MESSAGE_TEXT]}')
-            # dest_sock = self.clients[dest_name]
-            # # Сокет получателя в списке сокетов? -------------------
-            # if dest_sock in send_socks:
-            #     # LOGGER.debug(f'Отправляю сообщение [{dest_name}]: {msg}')
-            #     send_message(dest_sock, msg)
-            #     LOGGER.info(f'[{in_name}] => [{dest_name}]: {msg[MESSAGE_TEXT]}')
-            # else:
-            #     LOGGER.error(f'Ошибка: [{dest_name}] Пропал вслед за кораблем')
-            #     raise ConnectionError
+            LOGGER.info(f'[{send_cli}] => [ВСЕМ]: {msg[MESSAGE_TEXT]}')
+        elif dest_cli in self.clients and self.clients[dest_cli] in send_sock:
+            LOGGER.debug(f'Отправляю сообщение [{dest_cli}]: {msg}')
+            send_message(self.clients[dest_cli], msg)
+            LOGGER.info(f'[{send_cli}] => [{dest_cli}]: {msg[MESSAGE_TEXT]}')
+        elif dest_cli in self.clients and self.clients[dest_cli] not in send_sock:
+            LOGGER.error(f'Ошибка: [{dest_cli}] Пропал вслед за кораблем')
+            raise ConnectionError
         else:
-            LOGGER.debug(f'Отвечаю [{in_name}]: "Пользователь [{dest_name}] не найден, '
+            LOGGER.debug(f'Отправляю [{send_cli}] сообщение: "Пользователь [{dest_cli}] не найден, '
                          f'неудалось доставить: {msg[MESSAGE_TEXT]}"')
-            send_message(self.clients[in_name], {
-                RESPONSE: 400,
-                ERROR: f'Пользователь [{dest_name}] не в сети, не удалось доставить: {msg[MESSAGE_TEXT]}'})
-            LOGGER.error(f'Ошибка: Пользователь [{dest_name}] не найден, не удалось доставить: '
-                         f'[{in_name}] => [{dest_name}]: {msg[MESSAGE_TEXT]}')
+            send_message(self.clients[send_cli], {
+                ACTION: MESSAGE,
+                TIME: time(),
+                SENDER: 'SERVER',
+                DESTINATION: send_cli,
+                MESSAGE_TEXT: f'Пользователь [{dest_cli}] не найден, неудалось доставить: {msg[MESSAGE_TEXT]}'})
+            LOGGER.debug(f'Пользователь [{dest_cli}] не найден, неудалось доставить: [{send_cli}] => [{dest_cli}]: '
+                         f'{msg[MESSAGE_TEXT]}')
 
     @log
     def remove_client(self, sock_or_name):
-        """Метод удаляет из цикла обработки (отключает от сервера) пользователя. Принимает:
-        сокет или имя
-        """
         # LOGGER.info(f'Отключаю сокет/пользователя: {sock_or_name}')
         if type(sock_or_name) is socket:
             if sock_or_name in self.cli_socks:
@@ -321,7 +305,6 @@ class Core(threading.Thread, metaclass=ServerVerifier):
 
     @log
     def stop(self):
-        """Метод освобождает сокеты и сообщает об остановке сервера"""
         LOGGER.info(f'Завершение работы, отключаю {len(self.cli_socks)} клиентов...')
         for client in self.cli_socks:
             client.close()
@@ -330,7 +313,6 @@ class Core(threading.Thread, metaclass=ServerVerifier):
         LOGGER.info(f'Сервер остановлен')
 
     def init_socket(self):
-        """Метод создает серверный сокет для работы"""
         self.serv_sock = socket(AF_INET, SOCK_STREAM)
         self.serv_sock.setsockopt(SOL_SOCKET, SO_REUSEADDR, 1)
         self.serv_sock.bind((self.serv_ip, self.serv_port))
@@ -339,7 +321,7 @@ class Core(threading.Thread, metaclass=ServerVerifier):
         self.serv_sock.listen(MAX_CONNECTIONS)
 
     def service_update_lists(self):
-        """Метод реализующий отправки сервисного сообщения 205 клиентам"""
+        '''Метод реализующий отправки сервисного сообщения 205 клиентам.'''
         for client in self.clients:
             try:
                 send_message(self.clients[client], RESPONSE_205)
@@ -347,7 +329,6 @@ class Core(threading.Thread, metaclass=ServerVerifier):
                 self.remove_client(self.clients[client])
 
     def run(self):
-        """Метод основного цикла, получает и распределяет сообщения"""
         self.init_socket()
         # Ловим прерывание работы через Ctrl+C
         try:
